## 5/20 Follow Dart file conventions

### [x] 0/10 points: Provide a valid `pubspec.yaml`

<details>
<summary>
Sdk-constraint doesn't allow future stable dart 2.x releases
</summary>

`pubspec.yaml:6:8`

```
  ╷
6 │   sdk: ">=2.12.0-0 <2.12.0"
  │        ^^^^^^^^^^^^^^^^^^^^
  ╵
```

</details>
<details>
<summary>
The package description is too short.
</summary>

Add more detail to the `description` field of `pubspec.yaml`. Use 60 to 180 characters to describe the package, what it does, and its target use case.
</details>

### [*] 5/5 points: Provide a valid `README.md`


### [x] 0/5 points: Provide a valid `CHANGELOG.md`

<details>
<summary>
No `CHANGELOG.md` found.
</summary>

Changelog entries help developers follow the progress of your package. See the [example](https://raw.githubusercontent.com/dart-lang/stagehand/master/templates/package-simple/CHANGELOG.md) generated by `stagehand`.
</details>

## 0/10 Provide documentation

### [x] 0/10 points: Package has an example

<details>
<summary>
No example found.
</summary>

See [package layout](https://dart.dev/tools/pub/package-layout#examples) guidelines on how to add an example.
</details>

## 0/20 Support multiple platforms

### [x] 0/20 points: Supports 0 of 2 possible platforms (native, js)

<details>
<summary>
Package resolution failed. Could not determine platforms.
</summary>

Run `pub get` for more information.
</details>

## 30/30 Pass static analysis

### [*] 30/30 points: code has no errors, warnings, lints, or formatting issues


## 0/20 Support up-to-date dependencies

### [x] 0/10 points: All of the package dependencies are supported in the latest version

<details>
<summary>
Sdk constraint doesn't support current Dart version 2.12.0. Cannot run `pub outdated`.
</summary>

`pubspec.yaml:6:8`

```
  ╷
6 │   sdk: ">=2.12.0-0 <2.12.0"
  │        ^^^^^^^^^^^^^^^^^^^^
  ╵
```

</details>

### [x] 0/10 points: Package supports latest stable Dart and Flutter SDKs

<details>
<summary>
Sdk constraint doesn't support current Dart version 2.12.0.
</summary>

`pubspec.yaml:6:8`

```
  ╷
6 │   sdk: ">=2.12.0-0 <2.12.0"
  │        ^^^^^^^^^^^^^^^^^^^^
  ╵
```

Try widening the upper boundary of the constraint.
</details>
* Found no Flutter in your PATH. Could not determine the current Flutter version.

## 0/20 Support sound null safety

### [x] 0/20 points: Unable to detect null safety

<details>
<summary>
Package resolution failed. Could not determine null safety.
</summary>

Run `pub get` for more information.
</details>